==> moodle-1.5-pgsql.tgz: moodle/lang/nl/appointment.php <==
<?PHP // $Id$ 
      // appointment.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004093001)


$string['allowresubmit'] = 'Laat opnieuw inzenden toe';
$string['appointmentdetails'] = 'Details afspraak';
$string['appointmentlocation'] = 'Plaats afspraak';
$string['appointmentname'] = 'Naam afspraak';
$string['date'] = 'Datum van de afspraak';
$string['description'] = 'Beschrijving';
$string['early'] = '$a vroeg';
$string['failedupdatefeedback'] = 'Het updaten van de feedback op de inzending voor gebruiker $a is mislukt';
$string['feedback'] = 'Feedback';
$string['feedbackupdated'] = 'Feedback voor inzendingen gepdated voor $a geruikers';
$string['late'] = '$a te laat';
$string['maximumgrade'] = 'Maximumcijfer';
$string['maximumsize'] = 'Maximumgrootte';
$string['modulename'] = 'Afspraak';
$string['modulenameplural'] = 'Afspraken';
$string['newsubmissions'] = 'Afspraken ingestuurd';
$string['notgradedyet'] = 'Nog geen cijfer gegeven';
$string['notsubmittedyet'] = 'Nog niet ingezonden';
$string['overwritewarning'] = 'Waarschuwing: opnieuw uploaden zal je huidige inzending VERVANGEN';
$string['saveallfeedback'] = 'Bewaar al mijn feedback';
$string['submissionfeedback'] = 'Feedback bij inzending';
$string['submissions'] = 'Inzendingen';
$string['submitappointment'] = 'Stuur je afspraak in met dit formulier';
$string['submitted'] = 'Ingezonden';
$string['timeend'] = 'Einde van de afspraak';
$string['timestart'] = 'Begin van de afspraak';
$string['typeoffline'] = 'Off line activiteit';
$string['typeuploadsingle'] = 'Upload een bestand';
$string['uploadbadname'] = 'Deze bestandsnaam bevat vreemde tekens en kon niet geploaded worden';
$string['uploadedfiles'] = 'Geploade bestanden';
$string['uploaderror'] = 'Er is een fout gebeurd tijdens het bewaren van het bestand op de server';
$string['uploadfailnoupdate'] = 'Het bestand is goed geploaded, maar kon je inzending niet updaten!';
$string['uploadfiletoobig'] = 'Sorry, maar dit bestand is te groot (de limiet is $a bytes)';
$string['uploadnofilefound'] = 'Er is geen bestand gevonden - ben je er zeker van dat je er n geselecteerd hebt om te uploaden?';
$string['uploadnotregistered'] = '\'$a\' is goed geploadet, maar de inzending is niet geregistreerd!';
$string['uploadsuccess'] = '\'$a\' met succes geploaded';
$string['viewfeedback'] = 'Bekijk de cijfers en de feedback van de afspraak';
$string['viewsubmissions'] = 'Bekijk $a ingestuurde afspraken';
$string['yoursubmission'] = 'Jouw inzending';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/nl/appointment.php <==
<?PHP // $Id$ 
      // appointment.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004093001)


$string['allowresubmit'] = 'Laat opnieuw inzenden toe';
$string['appointmentdetails'] = 'Details afspraak';
$string['appointmentlocation'] = 'Plaats afspraak';
$string['appointmentname'] = 'Naam afspraak';
$string['date'] = 'Datum van de afspraak';
$string['description'] = 'Beschrijving';
$string['early'] = '$a vroeg';
$string['failedupdatefeedback'] = 'Het updaten van de feedback op de inzending voor gebruiker $a is mislukt';
$string['feedback'] = 'Feedback';
$string['feedbackupdated'] = 'Feedback voor inzendingen gepdatet voor $a gebruikers';
$string['late'] = '$a te laat';
$string['maximumgrade'] = 'Maximumcijfer';
$string['maximumsize'] = 'Maximumgrootte';
$string['modulename'] = 'Afspraak';
$string['modulenameplural'] = 'Afspraken';
$string['newsubmissions'] = 'Afspraken ingestuurd';
$string['notgradedyet'] = 'Nog geen cijfer gegeven';
$string['notsubmittedyet'] = 'Nog niet ingezonden';
$string['overwritewarning'] = 'Waarschuwing: opnieuw uploaden zal je huidige inzending VERVANGEN';
$string['saveallfeedback'] = 'Bewaar al mijn feedback';
$string['submissionfeedback'] = 'Feedback bij inzending';
$string['submissions'] = 'Inzendingen';
$string['submitappointment'] = 'Stuur je afspraak in met dit formulier';
$string['submitted'] = 'Ingezonden';
$string['timeend'] = 'Einde van de afspraak';
$string['timestart'] = 'Begin van de afspraak';
$string['typeoffline'] = 'Off line activiteit';
$string['typeuploadsingle'] = 'Upload een bestand';
$string['uploadbadname'] = 'Deze bestandsnaam bevat vreemde tekens en kon niet gepload worden';
$string['uploadedfiles'] = 'Geploade bestanden';
$string['uploaderror'] = 'Er is een fout gebeurd tijdens het bewaren van het bestand op de server';
$string['uploadfailnoupdate'] = 'Het bestand is goed gepload, maar kon je inzending niet updaten!';
$string['uploadfiletoobig'] = 'Sorry, maar dit bestand is te groot (de limiet is $a bytes)';
$string['uploadnofilefound'] = 'Er is geen bestand gevonden - ben je er zeker van dat je er n geselecteerd hebt om te uploaden?';
$string['uploadnotregistered'] = '\'$a\' is goed gepload, maar de inzending is niet geregistreerd!';
$string['uploadsuccess'] = '\'$a\' met succes gepload';
$string['viewfeedback'] = 'Bekijk de cijfers en de feedback van de afspraak';
$string['viewsubmissions'] = 'Bekijk $a ingestuurde afspraken';
$string['yoursubmission'] = 'Jouw inzending';

?>
